@@ -61,10 +61,11 @@ class Foreperson:
             self.data = {'column 1': 'Qz / Aa^-1', 'column 2': 'RQz', 'column 3': 'sigma RQz , standard deviation'}
         elif self.n_columns == 4:
             self.data = {'column 1': 'Qz / Aa^-1', 'column 2': 'RQz', 'column 3': 'sigma RQz , standard deviation', 'column 4': 'dQz-by-Qz , resolution'}
-        if 'creator' in metadata.keys():
-            self.creator = metadata['creator']
-        if 'data source' in metadata.keys():
-            self.data_source = metadata['data source']
+        if metadata is not None:
+            if 'creator' in metadata.keys():
+                self.creator = metadata['creator']
+            if 'data source' in metadata.keys():
+                self.data_source = metadata['data source']
         self.header = None
 
 
@@ -106,7 +107,7 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=Non
     the_boss.reduction['yaml'] = yaml_file
     keys = recipe.keys()
     if 'instrument' in keys:
-        the_boss.self.data_source['experiment']['instrument'] = recipe['instrument']
+        the_boss.data_source['experiment']['instrument'] = recipe['instrument']
         the_boss.parser = function_map[recipe['instrument']]
     else:
         raise ValueError("No instrument given in {}.".format(yaml_file))
